@@ -2,12 +2,13 @@ from __future__ import unicode_literals, annotations
 
 import json
 import re
+import datetime
 from enum import Enum
 from uuid import UUID
 from calendar import timegm
-import datetime
-from decimal import Decimal, localcontext
 from logging import getLogger
+from collections import namedtuple
+from decimal import Decimal, localcontext
 from ipaddress import IPv4Address, IPv6Address
 from typing import TYPE_CHECKING, Any, Optional, Union, Iterable
 
@@ -16,7 +17,7 @@ import pytz
 from pytz import BaseTzInfo
 
 from .utils import escape, parse_array, comma_join, string_or_func, get_subclass_names, parse_map
-from .funcs import F, FunctionOperatorsMixin
+from .funcs import F, FunctionOperatorsMixin, Lambda
 
 if TYPE_CHECKING:
     from clickhouse_orm.models import Model
@@ -684,6 +685,10 @@ class TupleField(Field):
             self.inner_fields.append(field)
         self.class_default = tuple(field.class_default for field in self.inner_fields)
         super().__init__(default, alias, materialized, readonly, codec, db_column)
+        if self.names:
+            self.tuple_field = namedtuple("TupleField", list(self.names.keys()))
+        else:
+            self.tuple_field = tuple
 
     def to_python(self, value, timezone_in_use) -> tuple:
         if isinstance(value, str):
@@ -698,8 +703,8 @@ class TupleField(Field):
             )
         elif not isinstance(value, (list, tuple)):
             raise ValueError("TupleField expects list or tuple, not %s" % type(value))
-        return tuple(
-            self.inner_fields[i].to_python(v, timezone_in_use) for i, v in enumerate(value)
+        return self.tuple_field(
+            *[self.inner_fields[i].to_python(v, timezone_in_use) for i, v in enumerate(value)]
         )
 
     def validate(self, value):
@@ -720,6 +725,14 @@ class TupleField(Field):
             sql += " CODEC(%s)" % self.codec
         return sql
 
+    def __getattr__(self, item):
+        if item in self.names:
+            return Lambda(f"{self.name}.{item}")
+        super(TupleField, self).__getattr__()
+
+    def __setattr__(self, key, value):
+        super(TupleField, self).__setattr__(key, value)
+
 
 class UUIDField(Field):
     class_default = UUID(int=0)
@@ -941,5 +954,12 @@ class MapField(Field):
             sql += " CODEC(%s)" % self.codec
         return sql
 
+
+class JSONField(Field):
+    """Experimental Field"""
+    class_default = {}
+    db_type = "JSON"
+
+
 # Expose only relevant classes in import *
 __all__ = get_subclass_names(locals(), Field)
